@@ -21,12 +21,13 @@
 # Just call autoreconf -i.  This script should really go away, but we're
 # keeping it, because people are used to it.
 rm -f ABOUT-NLS
-rm -f po/remove-potcdate.sin
-autoreconf -i
+autoreconf -fi
+
+# Make sure to regenerate .gitignore files
+touch git.mk
 
 # See https://savannah.gnu.org/bugs/index.php?54809
 rm -f \
-./po/remove-potcdate.sin \
 ./po/quot.sed \
 ./po/boldquot.sed \
 ./po/en@quot.header \
@@ -36,4 +37,3 @@ rm -f \
 ./ABOUT-NLS
 
 touch ABOUT-NLS
-touch po/remove-potcdate.sin
