@@ -24,7 +24,7 @@ A more convenient interface is provided by the 'Speaker' class.
 
 #TODO: Blocking variants for speak, char, key, sound_icon.
 
-import socket, sys, os, subprocess, time, tempfile
+import socket, os, subprocess, time, tempfile
 
 try:
     import threading
@@ -231,7 +231,7 @@ class _SSIP_Connection(object):
                 code, msg, data = self._recv_message()
             except IOError:
                 # If the socket has been closed, exit the thread
-                sys.exit()
+                return
             if code//100 != 7:
                 # This is not an index mark nor an event
                 self._com_buffer.append((code, msg, data))
@@ -283,6 +283,7 @@ class _SSIP_Connection(object):
             if sep == ' ':
                 msg = text
                 return int(code), msg, tuple(data)
+            c = code
             data.append(text)
 
     def _recv_response(self):
@@ -490,6 +491,11 @@ class SSIPClient(object):
     Dispatcher control application, however.  More datails can be found in
     Speech Dispatcher documentation.
 
+    Here is a simple example:
+
+    from speechd import client
+    c = client.SSIPClient("mytest")
+    c.speak("hello, world!")
     """
     
     DEFAULT_HOST = '127.0.0.1'
@@ -620,7 +626,7 @@ class SSIPClient(object):
         try:
             _method = address_params[0]
         except:
-            raise SSIPCommunicationErrror("Wrong format of server address")
+            raise SSIPCommunicationError("Wrong format of server address")
         connection_args['communication_method'] = _method
         if _method == CommunicationMethod.UNIX_SOCKET:
             try:
@@ -842,9 +848,12 @@ class SSIPClient(object):
         code, msg, data = self._conn.send_command('LIST', 'OUTPUT_MODULES')
         return data
 
-    def list_synthesis_voices(self):
+    def list_synthesis_voices(self, language=None, variant=None):
         """Return names of all available voices for the current output module.
 
+        If language (possibly even variant) is set, only the list matching that
+        language (possibly even variant) is returned.
+
         Returns a tuple of tripplets (name, language, variant).
 
         'name' is a string, 'language' is an ISO 639-1 Alpha-2/3 language code
@@ -852,7 +861,12 @@ class SSIPClient(object):
 
         """
         try:
-            code, msg, data = self._conn.send_command('LIST', 'SYNTHESIS_VOICES')
+            command = ['LIST', 'SYNTHESIS_VOICES']
+            if language:
+                command.append(language)
+                if variant:
+                    command.append(variant)
+            code, msg, data = self._conn.send_command(*command)
         except SSIPCommandError:
             return ()
         def split(item):
@@ -1085,7 +1099,7 @@ class SSIPClient(object):
         else:
             ssip_val = "OFF"
 
-        self._conn.send_command('SET', scope.ALL, 'DEBUG', ssip_val)
+        self._conn.send_command('SET', Scope.ALL, 'DEBUG', ssip_val)
 
 
     def set_debug_destination(self, path):
@@ -1097,9 +1111,9 @@ class SSIPClient(object):
           scope -- see the documentation of this class.
         
         """
-        assert isinstance(val, string)
+        assert isinstance(path, str)
 
-        self._conn.send_command('SET', scope.ALL, 'DEBUG_DESTINATION', val)
+        self._conn.send_command('SET', Scope.ALL, 'DEBUG_DESTINATION', path)
 
     def block_begin(self):
         """Begin an SSIP block.
