@@ -256,7 +256,6 @@ static gchar *escape_ssml_text(const gchar *text, struct tags **tags_ret, gint *
 	const gchar *cur, *curtag = NULL;
 	struct tags *tags;
 	GString *str;
-	gchar *result;
 	gchar name[7];		/* Current tag name, only need to recognize against "mark", "/mark", "!--" for now */
 	gsize namepos = 0;
 
@@ -408,10 +407,7 @@ static gchar *escape_ssml_text(const gchar *text, struct tags **tags_ret, gint *
 	*tags_ret = tags;
 	*ntags_ret = ntags;
 
-	result = str->str;
-	g_string_free(str, FALSE);
-
-	return result;
+	return g_string_free(str, FALSE);
 }
 
 /* Put back tags into the text */
@@ -419,7 +415,6 @@ static gchar *unescape_ssml_text(const gchar *text, struct tags *tags, gint ntag
 {
 	GString *str;
 	const gchar *cur;
-	gchar *result;
 	struct tags *curtags = tags;
 
 	str = g_string_sized_new(strlen(text));
@@ -460,10 +455,7 @@ static gchar *unescape_ssml_text(const gchar *text, struct tags *tags, gint ntag
 
 	free(tags);
 
-	result = str->str;
-	g_string_free(str, FALSE);
-
-	return result;
+	return g_string_free(str, FALSE);
 }
 
 /*----------------- Speech symbol representation and loading ----------------*/
@@ -712,6 +704,7 @@ static gpointer speech_symbols_new(const gchar *locale, const gchar *file)
 {
 	SpeechSymbols *ss = g_malloc(sizeof *ss);
 	gchar *path;
+	int ret;
 
 	ss->complex_symbols = NULL;
 	ss->source = NULL;
@@ -719,9 +712,20 @@ static gpointer speech_symbols_new(const gchar *locale, const gchar *file)
 					    g_free,
 					    (GDestroyNotify) speech_symbol_free);
 
-	path = g_build_filename(LOCALE_DATA, locale, file, NULL);
-	MSG2(5, "symbols", "Trying to load %s for '%s' from '%s'", file, locale, path);
-	if (speech_symbols_load(ss, path, TRUE) >= 0) {
+	path = g_build_filename(SpeechdOptions.user_conf_dir, "locale", locale, file, NULL);
+	MSG2(5, "symbols", "Trying to load %s for '%s' from '%s/locale'", file, locale, SpeechdOptions.user_conf_dir);
+	ret = speech_symbols_load(ss, path, TRUE);
+	if (ret < 0) {
+		path = g_build_filename(SpeechdOptions.user_conf_dir, "locale", file, NULL);
+		MSG2(5, "symbols", "Trying to load %s from '%s/locale'", file, SpeechdOptions.user_conf_dir);
+		ret = speech_symbols_load(ss, path, TRUE);
+	}
+	if (ret < 0) {
+		path = g_build_filename(LOCALE_DATA, locale, file, NULL);
+		MSG2(5, "symbols", "Trying to load %s for '%s' from '%s'", file, locale, path);
+		ret = speech_symbols_load(ss, path, TRUE);
+	}
+	if (ret >= 0) {
 		MSG2(5, "symbols", "Successful");
 		/* The elements are added to the start of the list in
 		 * speech_symbols_load_complex_symbol() for better speed (as adding to
@@ -851,7 +855,7 @@ static SpeechSymbolProcessor *speech_symbols_processor_new(const char *locale, S
 			SpeechSymbol *sym;
 
 			sym = g_hash_table_lookup(ssp->symbols, key);
-			if (!sym) {
+			if (!sym && syms != ssbase) {
 				/* This is a new simple symbol.
 				 * (All complex symbols have already been added.) */
 				sym = speech_symbol_new();
@@ -875,15 +879,17 @@ static SpeechSymbolProcessor *speech_symbols_processor_new(const char *locale, S
 					multi_chars_list = g_slist_prepend(multi_chars_list, sym->identifier);
 				}
 			}
-			/* If fields weren't explicitly specified, inherit the value from later sources. */
-			if (sym->replacement == NULL)
-				sym->replacement = g_strdup(source_sym->replacement);
-			if (sym->level == SYMLVL_INVALID)
-				sym->level = source_sym->level;
-			if (sym->preserve == SYMPRES_INVALID)
-				sym->preserve = source_sym->preserve;
-			if (sym->display_name == NULL)
-				sym->display_name = g_strdup(source_sym->display_name);
+			if (sym) {
+				/* If fields weren't explicitly specified, inherit the value from later sources. */
+				if (sym->replacement == NULL)
+					sym->replacement = g_strdup(source_sym->replacement);
+				if (sym->level == SYMLVL_INVALID)
+					sym->level = source_sym->level;
+				if (sym->preserve == SYMPRES_INVALID)
+					sym->preserve = source_sym->preserve;
+				if (sym->display_name == NULL)
+					sym->display_name = g_strdup(source_sym->display_name);
+			}
 		}
 	}
 
@@ -1430,4 +1436,6 @@ void insert_symbols(TSpeechDMessage *msg, int punct_missing)
 			if (g_utf8_strlen(processed, -1) > 1)
 				msg->settings.type = SPD_MSGTYPE_TEXT;
 	}
+
+	free(locale);
 }
