@@ -33,24 +33,26 @@
 
 int main()
 {
+	printf("Major: %d, Minor: %d, Micro: %d\n", LIBSPEECHD_MAJOR_VERSION, LIBSPEECHD_MINOR_VERSION, LIBSPEECHD_MICRO_VERSION);
+	
 	SPDConnection *conn;
 	int i, ret;
 
 	printf("Start of the test of the test.\n");
 
-	printf("Trying to initialize Speech Deamon...");
+	printf("Trying to initialize Speech Daemon...\n");
 	conn = spd_open("say", NULL, NULL, SPD_MODE_SINGLE);
 	if (conn == 0) {
-		printf("Speech Deamon failed");
+		printf("Speech Daemon failed.\n");
 		exit(1);
 	}
 	printf("OK\n");
 
 	printf("Say inviting message\n");
 	ret =
-	    spd_say(conn, SPD_MESSAGE, "Hello, how are you? I'm Speech Deamon");
+	    spd_say(conn, SPD_MESSAGE, "Hello, how are you? I'm Speech Daemon");
 	if (ret == -1) {
-		printf("spd_say failed");
+		printf("spd_say failed\n");
 		exit(1);
 	}
 
@@ -60,20 +62,20 @@ int main()
 	printf("Try to lower pitch and higher rate...\n");
 	ret = spd_set_voice_pitch(conn, -20);
 	if (ret == -1) {
-		printf("spd_set_voice_pitch failed");
+		printf("spd_set_voice_pitch failed\n");
 		exit(1);
 	}
 
 	ret = spd_set_voice_rate(conn, +20);
 	if (ret == -1) {
-		printf("spd_set_voice_rate failed");
+		printf("spd_set_voice_rate failed\n");
 		exit(1);
 	}
 
 	printf("...and say something\n");
 	ret = spd_say(conn, SPD_MESSAGE, "Do you like this voice more?");
 	if (ret == -1) {
-		printf("spd_say failed");
+		printf("spd_say failed\n");
 		exit(1);
 	}
 
@@ -83,45 +85,44 @@ int main()
 	printf("Try to lower pitch and raise pitch range and rate...\n");
 	ret = spd_set_voice_pitch(conn, -20);
 	if (ret == -1) {
-		printf("spd_set_voice_pitch failed");
+		printf("spd_set_voice_pitch failed\n");
 		exit(1);
 	}
 
 	ret = spd_set_voice_pitch_range(conn, +20);
 	if (ret == -1) {
-		printf("spd_set_voice_pitch_range failed");
+		printf("spd_set_voice_pitch_range failed\n");
 		exit(1);
 	}
 
 	ret = spd_set_voice_rate(conn, +20);
 	if (ret == -1) {
-		printf("spd_set_voice_rate failed");
+		printf("spd_set_voice_rate failed\n");
 		exit(1);
 	}
 
 	printf("...and say something\n");
 	ret = spd_say(conn, SPD_MESSAGE, "Do you like this voice more?");
 	if (ret == -1) {
-		printf("spd_say failed");
+		printf("spd_say failed\n");
 		exit(1);
 	}
 
 	sleep(4);
 
-	printf("Switch punctuation mode to `all'.");
-	printf("\n");
+	printf("Switch punctuation mode to `all'.\n");
 
 	printf("\n");
 	printf("Keep this pitch, set higher rate and let's test priorities.\n"
 	       "Priority progress should choose some messages\n"
-	       "to report the progrees and it should allways say\n"
+	       "to report the progrees and it should always say\n"
 	       "the last message.\n");
 
 	sleep(10);
 
 	ret = spd_set_voice_rate(conn, +90);
 	if (ret == -1) {
-		printf("spd_set_voice_rate failed");
+		printf("spd_set_voice_rate failed\n");
 		exit(1);
 	}
 
@@ -129,12 +130,12 @@ int main()
 		printf("%d%% completed\n", i);
 		ret = spd_sayf(conn, SPD_PROGRESS, "%d%% completed", i);
 		if (ret == -1) {
-			printf("spd_sayf failed");
+			printf("spd_sayf failed\n");
 			exit(1);
 		}
 	}
 
-	printf("Trying to close Speech Dispatcher connection...");
+	printf("Trying to close Speech Dispatcher connection...\n");
 	spd_close(conn);
 	printf("OK\n");
 
